[Pywps-commits] r1123 - trunk/pywps/Wps/Execute

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Wed Feb 9 11:46:23 CET 2011


Author: jesus
Date: 2011-02-09 11:46:20 +0100 (Wed, 09 Feb 2011)
New Revision: 1123

Modified:
   trunk/pywps/Wps/Execute/__init__.py
Log:
missing bool to str cast in LineageInput

Modified: trunk/pywps/Wps/Execute/__init__.py
===================================================================
--- trunk/pywps/Wps/Execute/__init__.py	2011-02-09 10:46:06 UTC (rev 1122)
+++ trunk/pywps/Wps/Execute/__init__.py	2011-02-09 10:46:20 UTC (rev 1123)
@@ -750,9 +750,9 @@
         self.templateProcessor.set("Inputs",templateInputs)
 
     def _lineageLiteralInput(self, input, wpsInput, literalInput):
         """ Fill input of literal data
         """
-        literalInput["literaldata"] = wpsInput["value"]
+        literalInput["literaldata"] = str(wpsInput["value"])
         literalInput["uom"] = str(input.uom)
         return literalInput
 
@@ -750,9 +750,9 @@
 
     def _lineageLiteralInput(self, input, wpsInput, literalInput):
-        """ Fill input of literal data
+        """ Fill input of literal data, boolean value will be cast to str
         """



More information about the Pywps-commits mailing list